from typing import Tuple, Set, Iterable, List


class StructuralSectionShape:
    NotDefined = 0
    RectangleParameterized = 2
    PipeStandard = 5
    IParallelFlange = 6
    ISlopedFlange = 7
    IWideFlange = 8
    CParallelFlange = 9
    CSlopedFlange = 10
    LAngle = 11
    RectangularBar = 12
    RoundBar = 13
    RectangleHSS = 14
    RoundHSS = 15
    IWelded = 16
    ISplitParallelFlange = 17
    ISplitSlopedFlange = 18
    StructuralTees = 19
    CProfile = 20
    CProfileWithLips = 21
    CProfileWithFold = 22
    LProfile = 23
    LProfileWithLips = 24
    ZProfile = 25
    ZProfileWithLips = 26
    SigmaProfile = 27
    SigmaProfileWithLips = 28
    SigmaProfileWithFold = 29
    UserDefined = 30
    ConcreteRectangle = 31
    ConcreteRectangleCut = 32
    ConcreteT = 33
    ConcreteCross = 34
    ConcreteRound = 35
    Invalid = -1


class StructuralSectionGeneralShape:
    NotDefined = 0
    GeneralI = 1
    GeneralC = 2
    GeneralU = 3
    GeneralLA = 4
    GeneralW = 5
    GeneralT = 6
    GeneralH = 7
    GeneralS = 8
    GeneralR = 9
    GeneralF = 10
    GeneralCEx = 11
    GeneralLZ = 12


class StructuralSection:
    def GetEnumerator(self) -> IEnumerator: ...
    @property
    def SectionNameKey(self) -> str: ...
    @SectionNameKey.setter
    def SectionNameKey(self, sectionNameKey: str) -> None: ...
    @property
    def AnalysisParams(self) -> StructuralSectionAnalysisParams: ...
    @property
    def StructuralSectionShape(self) -> StructuralSectionShape: ...
    @property
    def StructuralSectionGeneralShape(self) -> StructuralSectionGeneralShape: ...
    @property
    def StructuralSectionShapeName(self) -> str: ...
    @property
    def PrincipalAxesAngle(self) -> float: ...
    @PrincipalAxesAngle.setter
    def PrincipalAxesAngle(self, value: float) -> None: ...
    @property
    def SectionArea(self) -> float: ...
    @SectionArea.setter
    def SectionArea(self, value: float) -> None: ...
    @property
    def Perimeter(self) -> float: ...
    @Perimeter.setter
    def Perimeter(self, value: float) -> None: ...
    @property
    def NominalWeight(self) -> float: ...
    @NominalWeight.setter
    def NominalWeight(self, value: float) -> None: ...
    @property
    def MomentOfInertiaStrongAxis(self) -> float: ...
    @MomentOfInertiaStrongAxis.setter
    def MomentOfInertiaStrongAxis(self, value: float) -> None: ...
    @property
    def MomentOfInertiaWeakAxis(self) -> float: ...
    @MomentOfInertiaWeakAxis.setter
    def MomentOfInertiaWeakAxis(self, value: float) -> None: ...
    @property
    def ElasticModulusStrongAxis(self) -> float: ...
    @ElasticModulusStrongAxis.setter
    def ElasticModulusStrongAxis(self, value: float) -> None: ...
    @property
    def ElasticModulusWeakAxis(self) -> float: ...
    @ElasticModulusWeakAxis.setter
    def ElasticModulusWeakAxis(self, value: float) -> None: ...
    @property
    def PlasticModulusStrongAxis(self) -> float: ...
    @PlasticModulusStrongAxis.setter
    def PlasticModulusStrongAxis(self, value: float) -> None: ...
    @property
    def PlasticModulusWeakAxis(self) -> float: ...
    @PlasticModulusWeakAxis.setter
    def PlasticModulusWeakAxis(self, value: float) -> None: ...
    @property
    def TorsionalMomentOfInertia(self) -> float: ...
    @TorsionalMomentOfInertia.setter
    def TorsionalMomentOfInertia(self, value: float) -> None: ...
    @property
    def TorsionalModulus(self) -> float: ...
    @TorsionalModulus.setter
    def TorsionalModulus(self, value: float) -> None: ...
    @property
    def WarpingConstant(self) -> float: ...
    @WarpingConstant.setter
    def WarpingConstant(self, value: float) -> None: ...
    @property
    def ShearAreaStrongAxis(self) -> float: ...
    @ShearAreaStrongAxis.setter
    def ShearAreaStrongAxis(self, value: float) -> None: ...
    @property
    def ShearAreaWeakAxis(self) -> float: ...
    @ShearAreaWeakAxis.setter
    def ShearAreaWeakAxis(self, value: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetBoundarySize(self) -> UV: ...
    def Dispose(self) -> None: ...


class StructuralSectionAnalysisParams:
    @overload
    def __init__(self, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...
    @overload
    def __init__(self): ...
    @property
    def PrincipalAxesAngle(self) -> float: ...
    @PrincipalAxesAngle.setter
    def PrincipalAxesAngle(self, principalAxesAngle: float) -> None: ...
    @property
    def SectionArea(self) -> float: ...
    @SectionArea.setter
    def SectionArea(self, sectionArea: float) -> None: ...
    @property
    def Perimeter(self) -> float: ...
    @Perimeter.setter
    def Perimeter(self, perimeter: float) -> None: ...
    @property
    def NominalWeight(self) -> float: ...
    @NominalWeight.setter
    def NominalWeight(self, nominalWeight: float) -> None: ...
    @property
    def MomentOfInertiaStrongAxis(self) -> float: ...
    @MomentOfInertiaStrongAxis.setter
    def MomentOfInertiaStrongAxis(self, momentOfInertiaStrongAxis: float) -> None: ...
    @property
    def MomentOfInertiaWeakAxis(self) -> float: ...
    @MomentOfInertiaWeakAxis.setter
    def MomentOfInertiaWeakAxis(self, momentOfInertiaWeakAxis: float) -> None: ...
    @property
    def ElasticModulusStrongAxis(self) -> float: ...
    @ElasticModulusStrongAxis.setter
    def ElasticModulusStrongAxis(self, elasticModulusStrongAxis: float) -> None: ...
    @property
    def ElasticModulusWeakAxis(self) -> float: ...
    @ElasticModulusWeakAxis.setter
    def ElasticModulusWeakAxis(self, elasticModulusWeakAxis: float) -> None: ...
    @property
    def PlasticModulusStrongAxis(self) -> float: ...
    @PlasticModulusStrongAxis.setter
    def PlasticModulusStrongAxis(self, plasticModulusStrongAxis: float) -> None: ...
    @property
    def PlasticModulusWeakAxis(self) -> float: ...
    @PlasticModulusWeakAxis.setter
    def PlasticModulusWeakAxis(self, plasticModulusWeakAxis: float) -> None: ...
    @property
    def TorsionalMomentOfInertia(self) -> float: ...
    @TorsionalMomentOfInertia.setter
    def TorsionalMomentOfInertia(self, torsionalMomentOfInertia: float) -> None: ...
    @property
    def TorsionalModulus(self) -> float: ...
    @TorsionalModulus.setter
    def TorsionalModulus(self, torsionalModulus: float) -> None: ...
    @property
    def WarpingConstant(self) -> float: ...
    @WarpingConstant.setter
    def WarpingConstant(self, warpingConstant: float) -> None: ...
    @property
    def ShearAreaStrongAxis(self) -> float: ...
    @ShearAreaStrongAxis.setter
    def ShearAreaStrongAxis(self, shearAreaStrongAxis: float) -> None: ...
    @property
    def ShearAreaWeakAxis(self) -> float: ...
    @ShearAreaWeakAxis.setter
    def ShearAreaWeakAxis(self, shearAreaWeakAxis: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class StructuralSectionUtils:
    def GetStructuralSection(document: Document, elementId: ElementId) -> StructuralSection: ...
    def SetStructuralSection(document: Document, familySymbolId: ElementId, structuralSection: StructuralSection) -> bool: ...
    def GetStructuralElementDefinitionData(document: Document, elementId: ElementId) -> Tuple[StructuralSectionErrorCode, StructuralElementDefinitionData]: ...


class StructuralElementDefinitionData:
    def __init__(self): ...
    @property
    def Curve(self) -> Curve: ...
    @property
    def CenterCurve(self) -> Curve: ...
    @property
    def YJust(self) -> YJustification: ...
    @property
    def ZJust(self) -> ZJustification: ...
    @property
    def YOffset(self) -> float: ...
    @property
    def ZOffset(self) -> float: ...
    @property
    def StartShortening(self) -> float: ...
    @property
    def EndShortening(self) -> float: ...
    @property
    def Normal(self) -> XYZ: ...
    @property
    def Section(self) -> StructuralSection: ...
    @property
    def IsMirrored(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class StructuralSectionRound(StructuralSection):
    @property
    def Diameter(self) -> float: ...
    @Diameter.setter
    def Diameter(self, diameter: float) -> None: ...
    @property
    def CentroidHorizontal(self) -> float: ...
    @CentroidHorizontal.setter
    def CentroidHorizontal(self, centroidHorizontal: float) -> None: ...
    @property
    def CentroidVertical(self) -> float: ...
    @CentroidVertical.setter
    def CentroidVertical(self, centroidVertical: float) -> None: ...
    @property
    def NameKey(self) -> str: ...
    @NameKey.setter
    def NameKey(self, nameKey: str) -> None: ...


class StructuralSectionRectangular(StructuralSection):
    @property
    def Width(self) -> float: ...
    @Width.setter
    def Width(self, width: float) -> None: ...
    @property
    def Height(self) -> float: ...
    @Height.setter
    def Height(self, height: float) -> None: ...
    @property
    def CentroidHorizontal(self) -> float: ...
    @CentroidHorizontal.setter
    def CentroidHorizontal(self, centroidHorizontal: float) -> None: ...
    @property
    def CentroidVertical(self) -> float: ...
    @CentroidVertical.setter
    def CentroidVertical(self, centroidVertical: float) -> None: ...
    @property
    def NameKey(self) -> str: ...
    @NameKey.setter
    def NameKey(self, nameKey: str) -> None: ...


class StructuralSectionHotRolled(StructuralSectionRectangular):
    @property
    def FlangeThickness(self) -> float: ...
    @FlangeThickness.setter
    def FlangeThickness(self, flangeThickness: float) -> None: ...
    @property
    def FlangeThicknessLocation(self) -> float: ...
    @FlangeThicknessLocation.setter
    def FlangeThicknessLocation(self, flangeThicknessLocation: float) -> None: ...
    @property
    def WebThickness(self) -> float: ...
    @WebThickness.setter
    def WebThickness(self, webThickness: float) -> None: ...
    @property
    def WebThicknessLocation(self) -> float: ...
    @WebThicknessLocation.setter
    def WebThicknessLocation(self, webThicknessLocation: float) -> None: ...
    @property
    def WebFillet(self) -> float: ...
    @WebFillet.setter
    def WebFillet(self, webFillet: float) -> None: ...


class StructuralSectionColdFormed(StructuralSectionRectangular):
    @property
    def WallNominalThickness(self) -> float: ...
    @WallNominalThickness.setter
    def WallNominalThickness(self, wallNominalThickness: float) -> None: ...
    @property
    def WallDesignThickness(self) -> float: ...
    @WallDesignThickness.setter
    def WallDesignThickness(self, wallDesignThickness: float) -> None: ...
    @property
    def InnerFillet(self) -> float: ...
    @InnerFillet.setter
    def InnerFillet(self, innerFillet: float) -> None: ...


class StructuralSectionGeneralI(StructuralSectionHotRolled):
    def __init__(self, width: float, height: float, flangeThickness: float, flangeThicknessLocation: float, flangeFillet: float, flangeToeOfFillet: float, slopedFlangeAngle: float, webThickness: float, webFillet: float, webToeOfFillet: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def FlangeFillet(self) -> float: ...
    @FlangeFillet.setter
    def FlangeFillet(self, flangeFillet: float) -> None: ...
    @property
    def FlangeToeOfFillet(self) -> float: ...
    @FlangeToeOfFillet.setter
    def FlangeToeOfFillet(self, flangeToeOfFillet: float) -> None: ...
    @property
    def WebToeOfFillet(self) -> float: ...
    @WebToeOfFillet.setter
    def WebToeOfFillet(self, webToeOfFillet: float) -> None: ...
    @property
    def SlopedFlangeAngle(self) -> float: ...
    @SlopedFlangeAngle.setter
    def SlopedFlangeAngle(self, slopedFlangeAngle: float) -> None: ...
    def GetFlangeThicknessInQuarterWidth(self) -> float: ...
    def GetFlangeThicknessInFlangeCenter(self) -> float: ...


class StructuralSectionGeneralU(StructuralSectionHotRolled):
    def __init__(self, width: float, height: float, flangeThickness: float, flangeThicknessLocation: float, flangeFillet: float, flangeToeOfFillet: float, slopedFlangeAngle: float, webThickness: float, webFillet: float, webToeOfFillet: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def FlangeFillet(self) -> float: ...
    @FlangeFillet.setter
    def FlangeFillet(self, flangeFillet: float) -> None: ...
    @property
    def FlangeToeOfFillet(self) -> float: ...
    @FlangeToeOfFillet.setter
    def FlangeToeOfFillet(self, flangeToeOfFillet: float) -> None: ...
    @property
    def SlopedFlangeAngle(self) -> float: ...
    @SlopedFlangeAngle.setter
    def SlopedFlangeAngle(self, slopedFlangeAngle: float) -> None: ...
    @property
    def WebToeOfFillet(self) -> float: ...
    @WebToeOfFillet.setter
    def WebToeOfFillet(self, webToeOfFillet: float) -> None: ...
    def GetFlangeThicknessInWidthCenter(self) -> float: ...
    def GetFlangeThicknessInFlangeCenter(self) -> float: ...


class StructuralSectionGeneralC(StructuralSectionColdFormed):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, lipLength: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def LipLength(self) -> float: ...
    @LipLength.setter
    def LipLength(self, lipLength: float) -> None: ...


class StructuralSectionGeneralCEx(StructuralSectionColdFormed):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, lipLength: float, foldLength: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def LipLength(self) -> float: ...
    @LipLength.setter
    def LipLength(self, lipLength: float) -> None: ...
    @property
    def FoldLength(self) -> float: ...
    @FoldLength.setter
    def FoldLength(self, foldLength: float) -> None: ...


class StructuralSectionGeneralLZ(StructuralSectionColdFormed):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, bottomFlangeLength: float, lipLength: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def BottomFlangeLength(self) -> float: ...
    @BottomFlangeLength.setter
    def BottomFlangeLength(self, bottomFlangeLength: float) -> None: ...
    @property
    def LipLength(self) -> float: ...
    @LipLength.setter
    def LipLength(self, lipLength: float) -> None: ...


class StructuralSectionGeneralT(StructuralSectionHotRolled):
    def __init__(self, width: float, height: float, flangeThickness: float, flangeThicknessLocation: float, flangeFillet: float, flangeToeOfFillet: float, slopedFlangeAngle: float, webThickness: float, webThicknessLocation: float, webFillet: float, topWebFillet: float, webToeOfFillet: float, slopedWebAngle: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def FlangeFillet(self) -> float: ...
    @FlangeFillet.setter
    def FlangeFillet(self, flangeFillet: float) -> None: ...
    @property
    def FlangeToeOfFillet(self) -> float: ...
    @FlangeToeOfFillet.setter
    def FlangeToeOfFillet(self, flangeToeOfFillet: float) -> None: ...
    @property
    def SlopedFlangeAngle(self) -> float: ...
    @SlopedFlangeAngle.setter
    def SlopedFlangeAngle(self, slopedFlangeAngle: float) -> None: ...
    @property
    def TopWebFillet(self) -> float: ...
    @TopWebFillet.setter
    def TopWebFillet(self, topWebFillet: float) -> None: ...
    @property
    def WebToeOfFillet(self) -> float: ...
    @WebToeOfFillet.setter
    def WebToeOfFillet(self, webToeOfFillet: float) -> None: ...
    @property
    def SlopedWebAngle(self) -> float: ...
    @SlopedWebAngle.setter
    def SlopedWebAngle(self, slopedWebAngle: float) -> None: ...
    def GetFlangeThicknessInQuarterWidth(self) -> float: ...
    def GetFlangeThicknessInFlangeCenter(self) -> float: ...
    def GetWebThicknessInHeightCenter(self) -> float: ...


class StructuralSectionGeneralLA(StructuralSectionColdFormed):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, lipLength: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def LipLength(self) -> float: ...
    @LipLength.setter
    def LipLength(self, lipLength: float) -> None: ...


class StructuralSectionGeneralW(StructuralSectionHotRolled):
    def __init__(self, width: float, height: float, flangeThickness: float, webThickness: float, webFillet: float, flangeFillet: float, topWebFillet: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def FlangeFillet(self) -> float: ...
    @FlangeFillet.setter
    def FlangeFillet(self, flangeFillet: float) -> None: ...
    @property
    def TopWebFillet(self) -> float: ...
    @TopWebFillet.setter
    def TopWebFillet(self, topWebFillet: float) -> None: ...


class StructuralSectionGeneralH(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, outerFillet: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def WallNominalThickness(self) -> float: ...
    @WallNominalThickness.setter
    def WallNominalThickness(self, wallNominalThickness: float) -> None: ...
    @property
    def WallDesignThickness(self) -> float: ...
    @WallDesignThickness.setter
    def WallDesignThickness(self, wallDesignThickness: float) -> None: ...
    @property
    def InnerFillet(self) -> float: ...
    @InnerFillet.setter
    def InnerFillet(self, innerFillet: float) -> None: ...
    @property
    def OuterFillet(self) -> float: ...
    @OuterFillet.setter
    def OuterFillet(self, outerFillet: float) -> None: ...


class StructuralSectionGeneralS(StructuralSectionRound):
    def __init__(self, diameter: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...


class StructuralSectionGeneralR(StructuralSectionRound):
    def __init__(self, diameter: float, wallNominalThickness: float, wallDesignThickness: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...
    @property
    def WallNominalThickness(self) -> float: ...
    @WallNominalThickness.setter
    def WallNominalThickness(self, wallNominalThickness: float) -> None: ...
    @property
    def WallDesignThickness(self) -> float: ...
    @WallDesignThickness.setter
    def WallDesignThickness(self, wallDesignThickness: float) -> None: ...


class StructuralSectionGeneralF(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, analysisParams: StructuralSectionAnalysisParams): ...


class StructuralSectionPipeStandard(StructuralSectionGeneralR):
    def __init__(self, diameter: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, wallNominalThickness: float, wallDesignThickness: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionRectangleParameterized(StructuralSectionGeneralF):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionIParallelFlange(StructuralSectionGeneralI):
    def __init__(self, width: float, height: float, flangeThickness: float, webThickness: float, webFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, clearWebHeight: float, flangeToeOfFillet: float, webToeOfFillet: float, boltSpacing: float, boltDiameter: float): ...
    @property
    def ClearWebHeight(self) -> float: ...
    @ClearWebHeight.setter
    def ClearWebHeight(self, clearWebHeight: float) -> None: ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionISplitParallelFlange(StructuralSectionGeneralT):
    def __init__(self, width: float, height: float, flangeThickness: float, webThickness: float, webFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, clearWebHeight: float, flangeToeOfFillet: float, webToeOfFillet: float, boltSpacing: float, boltDiameter: float): ...
    @property
    def ClearWebHeight(self) -> float: ...
    @ClearWebHeight.setter
    def ClearWebHeight(self, clearWebHeight: float) -> None: ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionISlopedFlange(StructuralSectionGeneralI):
    def __init__(self, width: float, height: float, flangeThickness: float, flangeThicknessLocation: float, webThickness: float, webFillet: float, flangeFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, clearWebHeight: float, webToeOfFillet: float, boltSpacing: float, boltDiameter: float, slopedFlangeAngle: float): ...
    @property
    def ClearWebHeight(self) -> float: ...
    @ClearWebHeight.setter
    def ClearWebHeight(self, clearWebHeight: float) -> None: ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionCParallelFlange(StructuralSectionGeneralU):
    def __init__(self, width: float, height: float, flangeThickness: float, webThickness: float, webFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, clearWebHeight: float, flangeToeOfFillet: float, webToeOfFillet: float, boltSpacing: float, boltDiameter: float): ...
    @property
    def ClearWebHeight(self) -> float: ...
    @ClearWebHeight.setter
    def ClearWebHeight(self, clearWebHeight: float) -> None: ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionCSlopedFlange(StructuralSectionGeneralU):
    def __init__(self, width: float, height: float, flangeThickness: float, flangeThicknessLocation: float, webThickness: float, webFillet: float, flangeFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, clearWebHeight: float, webToeOfFillet: float, boltSpacing: float, boltDiameter: float, slopedFlangeAngle: float): ...
    @property
    def ClearWebHeight(self) -> float: ...
    @ClearWebHeight.setter
    def ClearWebHeight(self, clearWebHeight: float) -> None: ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionLAngle(StructuralSectionGeneralW):
    def __init__(self, width: float, height: float, flangeThickness: float, webThickness: float, webFillet: float, flangeFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, boltSpacing1LongerFlange: float, boltSpacing2LongerFlange: float, boltSpacingShorterFlange: float, boltDiameterLongerFlange: float, boltDiameterShorterFlange: float, topWebFillet: float): ...
    @property
    def BoltSpacing1LongerFlange(self) -> float: ...
    @BoltSpacing1LongerFlange.setter
    def BoltSpacing1LongerFlange(self, boltSpacing1LongerFlange: float) -> None: ...
    @property
    def BoltSpacing2LongerFlange(self) -> float: ...
    @BoltSpacing2LongerFlange.setter
    def BoltSpacing2LongerFlange(self, boltSpacing2LongerFlange: float) -> None: ...
    @property
    def BoltSpacingShorterFlange(self) -> float: ...
    @BoltSpacingShorterFlange.setter
    def BoltSpacingShorterFlange(self, boltSpacingShorterFlange: float) -> None: ...
    @property
    def BoltDiameterLongerFlange(self) -> float: ...
    @BoltDiameterLongerFlange.setter
    def BoltDiameterLongerFlange(self, boltDiameterLongerFlange: float) -> None: ...
    @property
    def BoltDiameterShorterFlange(self) -> float: ...
    @BoltDiameterShorterFlange.setter
    def BoltDiameterShorterFlange(self, boltDiameterShorterFlange: float) -> None: ...


class StructuralSectionStructuralTees(StructuralSectionGeneralT):
    def __init__(self, width: float, height: float, flangeThickness: float, flangeThicknessLocation: float, webThickness: float, webThicknessLocation: float, webFillet: float, flangeFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, boltSpacing: float, boltSpacingWeb: float, boltDiameter: float, slopedFlangeAngle: float, slopedWebAngle: float, topWebFillet: float): ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltSpacingWeb(self) -> float: ...
    @BoltSpacingWeb.setter
    def BoltSpacingWeb(self, boltSpacingWeb: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionISplitSlopedFlange(StructuralSectionGeneralT):
    def __init__(self, width: float, height: float, flangeThickness: float, flangeThicknessLocation: float, webThickness: float, webFillet: float, flangeFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, clearWebHeight: float, webToeOfFillet: float, boltSpacing: float, boltDiameter: float, slopedFlangeAngle: float): ...
    @property
    def ClearWebHeight(self) -> float: ...
    @ClearWebHeight.setter
    def ClearWebHeight(self, clearWebHeight: float) -> None: ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionIWideFlange(StructuralSectionHotRolled):
    def __init__(self, width: float, height: float, flangeThickness: float, webThickness: float, webFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, clearWebHeight: float, flangeToeOfFillet: float, webToeOfFillet: float, boltSpacing: float, boltSpacingTwoRows: float, boltSpacingBetweenRows: float, boltDiameter: float): ...
    @property
    def ClearWebHeight(self) -> float: ...
    @ClearWebHeight.setter
    def ClearWebHeight(self, clearWebHeight: float) -> None: ...
    @property
    def FlangeToeOfFillet(self) -> float: ...
    @FlangeToeOfFillet.setter
    def FlangeToeOfFillet(self, flangeToeOfFillet: float) -> None: ...
    @property
    def WebToeOfFillet(self) -> float: ...
    @WebToeOfFillet.setter
    def WebToeOfFillet(self, webToeOfFillet: float) -> None: ...
    @property
    def BoltSpacing(self) -> float: ...
    @BoltSpacing.setter
    def BoltSpacing(self, boltSpacing: float) -> None: ...
    @property
    def BoltSpacingTwoRows(self) -> float: ...
    @BoltSpacingTwoRows.setter
    def BoltSpacingTwoRows(self, boltSpacingTwoRows: float) -> None: ...
    @property
    def BoltSpacingBetweenRows(self) -> float: ...
    @BoltSpacingBetweenRows.setter
    def BoltSpacingBetweenRows(self, boltSpacingBetweenRows: float) -> None: ...
    @property
    def BoltDiameter(self) -> float: ...
    @BoltDiameter.setter
    def BoltDiameter(self, boltDiameter: float) -> None: ...


class StructuralSectionRectangularBar(StructuralSectionGeneralF):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionRoundBar(StructuralSectionGeneralS):
    def __init__(self, diameter: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionIWelded(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, topFlangeThickness: float, topFlangeWidth: float, bottomFlangeThickness: float, bottomFlangeWidth: float, webThickness: float, webHeight: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...
    @property
    def TopFlangeThickness(self) -> float: ...
    @TopFlangeThickness.setter
    def TopFlangeThickness(self, topFlangeThickness: float) -> None: ...
    @property
    def TopFlangeWidth(self) -> float: ...
    @TopFlangeWidth.setter
    def TopFlangeWidth(self, topFlangeWidth: float) -> None: ...
    @property
    def BottomFlangeThickness(self) -> float: ...
    @BottomFlangeThickness.setter
    def BottomFlangeThickness(self, bottomFlangeThickness: float) -> None: ...
    @property
    def BottomFlangeWidth(self) -> float: ...
    @BottomFlangeWidth.setter
    def BottomFlangeWidth(self, bottomFlangeWidth: float) -> None: ...
    @property
    def WebThickness(self) -> float: ...
    @WebThickness.setter
    def WebThickness(self, webThickness: float) -> None: ...
    @property
    def WebHeight(self) -> float: ...
    @WebHeight.setter
    def WebHeight(self, webHeight: float) -> None: ...


class StructuralSectionRectangleHSS(StructuralSectionGeneralH):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, outerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionRoundHSS(StructuralSectionGeneralR):
    def __init__(self, diameter: float, wallNominalThickness: float, wallDesignThickness: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionCProfile(StructuralSectionGeneralC):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionCProfileWithLips(StructuralSectionGeneralC):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, lipLength: float): ...


class StructuralSectionCProfileWithFold(StructuralSectionGeneralCEx):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, lipLength: float, foldLength: float): ...


class StructuralSectionLProfile(StructuralSectionGeneralLA):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionLProfileWithLips(StructuralSectionGeneralLA):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, lipLength: float): ...


class StructuralSectionZProfile(StructuralSectionGeneralLZ):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, bottomFlangeLength: float): ...


class StructuralSectionZProfileWithLips(StructuralSectionGeneralLZ):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, bottomFlangeLength: float, lipLength: float): ...


class StructuralSectionSigmaProfile(StructuralSectionColdFormed):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, bendWidth: float, middleBendLength: float, topBendLength: float): ...
    @property
    def BendWidth(self) -> float: ...
    @BendWidth.setter
    def BendWidth(self, bendWidth: float) -> None: ...
    @property
    def MiddleBendLength(self) -> float: ...
    @MiddleBendLength.setter
    def MiddleBendLength(self, middleBendLength: float) -> None: ...
    @property
    def TopBendLength(self) -> float: ...
    @TopBendLength.setter
    def TopBendLength(self, topBendLength: float) -> None: ...


class StructuralSectionSigmaProfileWithLips(StructuralSectionColdFormed):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, lipLength: float, bendWidth: float, middleBendLength: float, topBendLength: float): ...
    @property
    def BendWidth(self) -> float: ...
    @BendWidth.setter
    def BendWidth(self, bendWidth: float) -> None: ...
    @property
    def LipLength(self) -> float: ...
    @LipLength.setter
    def LipLength(self, lipLength: float) -> None: ...
    @property
    def MiddleBendLength(self) -> float: ...
    @MiddleBendLength.setter
    def MiddleBendLength(self, middleBendLength: float) -> None: ...
    @property
    def TopBendLength(self) -> float: ...
    @TopBendLength.setter
    def TopBendLength(self, topBendLength: float) -> None: ...


class StructuralSectionSigmaProfileWithFold(StructuralSectionColdFormed):
    def __init__(self, width: float, height: float, wallNominalThickness: float, wallDesignThickness: float, innerFillet: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, foldWidth: float, lipLength: float, bendWidth: float, middleBendLength: float, topBendLength: float): ...
    @property
    def FoldWidth(self) -> float: ...
    @FoldWidth.setter
    def FoldWidth(self, foldWidth: float) -> None: ...
    @property
    def BendWidth(self) -> float: ...
    @BendWidth.setter
    def BendWidth(self, bendWidth: float) -> None: ...
    @property
    def LipLength(self) -> float: ...
    @LipLength.setter
    def LipLength(self, lipLength: float) -> None: ...
    @property
    def MiddleBendLength(self) -> float: ...
    @MiddleBendLength.setter
    def MiddleBendLength(self, middleBendLength: float) -> None: ...
    @property
    def TopBendLength(self) -> float: ...
    @TopBendLength.setter
    def TopBendLength(self, topBendLength: float) -> None: ...


class StructuralSectionUserDefined(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionConcreteRectangle(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionConcreteRectangleCut(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, topCutWidth: float, topCutHeight: float, bottomCutWidth: float, bottomCutHeight: float): ...
    @property
    def TopCutWidth(self) -> float: ...
    @TopCutWidth.setter
    def TopCutWidth(self, topCutWidth: float) -> None: ...
    @property
    def TopCutHeight(self) -> float: ...
    @TopCutHeight.setter
    def TopCutHeight(self, topCutHeight: float) -> None: ...
    @property
    def BottomCutWidth(self) -> float: ...
    @BottomCutWidth.setter
    def BottomCutWidth(self, bottomCutWidth: float) -> None: ...
    @property
    def BottomCutHeight(self) -> float: ...
    @BottomCutHeight.setter
    def BottomCutHeight(self, bottomCutHeight: float) -> None: ...


class StructuralSectionConcreteT(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, cantileverLength: float, cantileverHeight: float): ...
    @property
    def CantileverLength(self) -> float: ...
    @CantileverLength.setter
    def CantileverLength(self, cantileverLength: float) -> None: ...
    @property
    def CantileverHeight(self) -> float: ...
    @CantileverHeight.setter
    def CantileverHeight(self, cantileverHeight: float) -> None: ...


class StructuralSectionConcreteCross(StructuralSectionRectangular):
    def __init__(self, width: float, height: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float, cantileverLength: float, cantileverHeight: float): ...
    @property
    def CantileverLength(self) -> float: ...
    @CantileverLength.setter
    def CantileverLength(self, cantileverLength: float) -> None: ...
    @property
    def CantileverHeight(self) -> float: ...
    @CantileverHeight.setter
    def CantileverHeight(self, cantileverHeight: float) -> None: ...


class StructuralSectionConcreteRound(StructuralSectionRound):
    def __init__(self, diameter: float, centroidHorizontal: float, centroidVertical: float, principalAxesAngle: float, sectionArea: float, perimeter: float, nominalWeight: float, momentOfInertiaStrongAxis: float, momentOfInertiaWeakAxis: float, elasticModulusStrongAxis: float, elasticModulusWeakAxis: float, plasticModulusStrongAxis: float, plasticModulusWeakAxis: float, torsionalMomentOfInertia: float, torsionalModulus: float, warpingConstant: float, shearAreaStrongAxis: float, shearAreaWeakAxis: float): ...


class StructuralSectionErrorCode:
    Success = 0
    Failure = 1
    ShapeNotRecognized = 2
    IncompleteDefinition = 3
    ElementNotSupported = 4
    MediumDetailShapeHasRounding = 5
    MediumAndFineDetailShapesAreInconsistent = 6
    ElementHasIndependentJustification = 7



""" FlexForm """  #

from itertools import count

from rpw.utils.dotnet import Enum
from rpw.ui.forms.resources import *


class FlexForm(Window):
    """
    Flex Form Usage

    >>> from rpw.ui.forms import (FlexForm, Label, ComboBox, TextBox, TextBox,
    ...                           Separator, Button, CheckBox)
    >>> components = [Label('Pick Style:'),
    ...               ComboBox('combobox1', {'Opt 1': 10.0, 'Opt 2': 20.0}),
    ...               Label('Enter Name:'),
    ...               TextBox('textbox1', Text="Default Value"),
    ...               CheckBox('checkbox1', 'Check this'),
    ...               Separator(),
    ...               Button('Select')]
    >>> form = FlexForm('Title', components)
    >>> form.show()
    >>> # User selects `Opt 1`, types 'Wood' in TextBox, and select Checkbox
    >>> form.values
    {'combobox1': 10.0, 'textbox1': 'Wood', 'checkbox': True}

    """
    layout = """
            <Window
                xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
                xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
                xmlns:d="http://schemas.microsoft.com/expression/blend/2008"
                xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
                xmlns:local="clr-namespace:WpfApplication1" mc:Ignorable="d"
                ResizeMode="NoResize"
                WindowStartupLocation="CenterScreen"
                Topmost="True"
                SizeToContent="WidthAndHeight">

                <Grid Name="MainGrid" Margin="10,10,10,10">
                </Grid>
            </Window>
            """

    def __init__(self, title, components, **kwargs):
        """
        Args:
            title (``str``): Form Title
            components (``list``): List of Form Components.
            top_offset (``float``): Optional top offset.
            options (``kwargs``): WPF Parameters Options

        Attributes:
            values (``dict``): Dictionary of selected values
        """

        self.ui = wpf.LoadComponent(self, StringReader(self.layout))
        self.ui.Title = title
        self.values = {}

        for key, value in kwargs.iteritems():
            setattr(self, key, value)

        for n, component in enumerate(components):
            self.MainGrid.Children.Add(component)
            if hasattr(component, 'on_click'):
                component.Click += component.on_click

            V_SPACE = 5
            if n > 0:
                prev_comp = components[n - 1]
                top = prev_comp.Margin.Top + prev_comp.Height + V_SPACE
                top += getattr(component, 'top_offset', 0)
                component.Margin = Thickness(0, top, 0, 0)

    def show(self):
        """
        Initializes Form. Returns ``True`` or ``False`` if form was exited.
        """
        return self.ShowDialog()

    @staticmethod
    def get_values(sender, e):
        """
        Default Get Values. Set form.values attribute with values from controls
        and closes form.
        """
        component_values = {}
        window = Window.GetWindow(sender)
        for component in window.MainGrid.Children:
            try:
                component_values[component.Name] = component.value
            except AttributeError:
                pass
        window.values = component_values
        window.close()

    def close(self):
        """ Exits Form. Returns ``True`` to ``show()`` method """
        self.DialogResult = True
        self.Close()


class RpwControlMixin():
    """ Control Mixin """
    _index = count(0)

    def __init__(self, **kwargs):
        self.set_attrs(**kwargs)

    def set_attrs(self, **kwargs):
        """ Parses kwargs, sets default values where appropriate. """
        self.index = next(self._index)  # Counts Instatiation to control Height

        # Default Values
        control_type = self.__class__.__name__
        if not self.Name:
            self.Name = kwargs.get('Name', '{}_{}'.format(control_type, self.index))

        self.Width = kwargs.get('Width', 300)
        self.Height = kwargs.get('Height', 25)

        h_align = Enum.Parse(HorizontalAlignment, kwargs.get('h_align', 'Left'))
        self.HorizontalAlignment = h_align
        v_align = Enum.Parse(VerticalAlignment, kwargs.get('v_align', 'Top'))
        self.VerticalAlignment = v_align

        # Inject Any other Custom Values into Component
        # Updating __dict__ fails due to how .NET inheritance/properties works
        for key, value in kwargs.iteritems():
            setattr(self, key, value)


class Label(RpwControlMixin, Controls.Label):
    """
    Windows.Controls.Label Wrapper

    >>> Label('Label Text')
    """
    def __init__(self, label_text, **kwargs):
        """
        Args:
            label_text (``str``): Label Text
            wpf_params (kwargs): Additional WPF attributes
        """
        self.Content = label_text
        self.set_attrs(**kwargs)


class TextBox(RpwControlMixin, Controls.TextBox):
    """
    Windows.Controls.TextBox Wrapper

    >>> TextBox()
    """
    def __init__(self, name, default='', **kwargs):
        """
        Args:
            name (``str``): Name of control. Will be used to return value
            default (``bool``): Sets ``Text`` attribute of textbox [Default: '']
            wpf_params (kwargs): Additional WPF attributes
        """
        self.Name = name
        self.Text = default
        self.set_attrs(**kwargs)
        if 'Height' not in kwargs:
            self.Height = 25

    @property
    def value(self):
        return self.Text


class Button(RpwControlMixin, Controls.Button):
    """
    Windows.Controls.Button Wrapper

    >>> Button('Select')
    """
    def __init__(self, button_text, on_click=None, **kwargs):
        """
        Args:
            button_text (``str``): Button Text
            on_click (``func``): Registers Click event Function [Default: :any:`FlexForm.get_values`]
            wpf_params (kwargs): Additional WPF attributes
        """
        self.Content = button_text
        self.on_click = on_click or FlexForm.get_values
        self.set_attrs(**kwargs)


class CheckBox(RpwControlMixin, Controls.CheckBox):
    """
    Windows.Controls.Checkbox Wrapper

    >>> CheckBox('Label')
    """
    def __init__(self, name, checkbox_text, default=False, **kwargs):
        """
        Args:
            name (``str``): Name of control. Will be used to return value
            checkbox_text (``str``): Checkbox label Text
            default (``bool``): Sets IsChecked state [Default: False]
            wpf_params (kwargs): Additional WPF attributes
        """
        self.Name = name
        self.Content = checkbox_text
        self.IsChecked = default
        self.set_attrs(top_offset=5, **kwargs)

    @property
    def value(self):
        return self.IsChecked


class ComboBox(RpwControlMixin, Controls.ComboBox):
    """
    Windows.Controls.ComboBox Wrapper

    >>> ComboBox({'Option 1': Element, 'Option 2', 'Elemnet'})
    >>> ComboBox({'Option 1': Element, 'Option 2', 'Elemnet'}, sort=False)
    """
    def __init__(self, name, options, default=None, sort=True, **kwargs):
        """
        Args:
            name (``str``): Name of control. Will be used to return value
            options (``list``, ``dict``): If ``dict``, selected value is returned
            default (``str``): Sets SelectedItem attribute [Default: first]
            wpf_params (kwargs): Additional WPF attributes
        """
        self.Name = name
        self.set_attrs(**kwargs)
        index = 0

        self.options = options
        if hasattr(options, 'keys'):
            options = options.keys()
        if sort:
            options.sort()
        if default is None:
            index = 0
        else:
            index = options.index(default)

        self.Items.Clear()
        self.ItemsSource = options
        self.SelectedItem = options[index]

    @property
    def value(self):
        selected = self.SelectedItem
        if isinstance(self.options, dict):
            selected = self.options[selected]
        return selected

class Separator(RpwControlMixin, Controls.Separator):
    """ WPF Separator """


if __name__ == '__main__':
    """ TESTS """
    components = [
                  Label('Pick Style:'),
                  ComboBox('combobox1', {'Opt 1': 10.0, 'Opt 2': 20.0}),
                  Label('Enter Name:'),
                  TextBox('textbox1', Text="Default Value"),
                  CheckBox('checkbox1', 'Check this:'),
                  Separator(),
                  Button('Select')]

    form = FlexForm('Title', components)
    form.show()

    print(form.values)



# encoding: utf-8
# module System.Collections.ObjectModel calls itself ObjectModel
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Collection(object,IList[T],ICollection[T],IEnumerable[T],IEnumerable,IList,ICollection,IReadOnlyList[T],IReadOnlyCollection[T]):
 """
 Collection[T]()

 Collection[T](list: IList[T])
 """
 def Add(self,item):
  """
  Add(self: Collection[T],item: T)

   Adds an object to the end of the System.Collections.ObjectModel.Collection.

  

   item: The object to be added to the end of the System.Collections.ObjectModel.Collection. The value 

    can be null for reference types.
  """
  pass
 def Clear(self):
  """
  Clear(self: Collection[T])

   Removes all elements from the System.Collections.ObjectModel.Collection.
  """
  pass
 def ClearItems(self,*args):
  """
  ClearItems(self: Collection[T])

   Removes all elements from the System.Collections.ObjectModel.Collection.
  """
  pass
 def Contains(self,item):
  """
  Contains(self: Collection[T],item: T) -> bool

  

   Determines whether an element is in the System.Collections.ObjectModel.Collection.

  

   item: The object to locate in the System.Collections.ObjectModel.Collection. The value can be null for 

    reference types.

  

   Returns: true if item is found in the System.Collections.ObjectModel.Collection; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """ CopyTo(self: Collection[T],array: Array[T],index: int) """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: Collection[T]) -> IEnumerator[T]

  

   Returns an enumerator that iterates through the System.Collections.ObjectModel.Collection.

   Returns: An System.Collections.Generic.IEnumerator for the System.Collections.ObjectModel.Collection.
  """
  pass
 def IndexOf(self,item):
  """
  IndexOf(self: Collection[T],item: T) -> int

  

   Searches for the specified object and returns the zero-based index of the first occurrence 

    within the entire System.Collections.ObjectModel.Collection.

  

  

   item: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   Returns: The zero-based index of the first occurrence of item within the entire 

    System.Collections.ObjectModel.Collection,if found; otherwise,-1.
  """
  pass
 def Insert(self,index,item):
  """
  Insert(self: Collection[T],index: int,item: T)

   Inserts an element into the System.Collections.ObjectModel.Collection at the specified index.

  

   index: The zero-based index at which item should be inserted.

   item: The object to insert. The value can be null for reference types.
  """
  pass
 def InsertItem(self,*args):
  """
  InsertItem(self: Collection[T],index: int,item: T)

   Inserts an element into the System.Collections.ObjectModel.Collection at the specified index.

  

   index: The zero-based index at which item should be inserted.

   item: The object to insert. The value can be null for reference types.
  """
  pass
 def Remove(self,item):
  """
  Remove(self: Collection[T],item: T) -> bool

  

   Removes the first occurrence of a specific object from the 

    System.Collections.ObjectModel.Collection.

  

  

   item: The object to remove from the System.Collections.ObjectModel.Collection. The value can be null 

    for reference types.

  

   Returns: true if item is successfully removed; otherwise,false.  This method also returns false if item 

    was not found in the original System.Collections.ObjectModel.Collection.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: Collection[T],index: int)

   Removes the element at the specified index of the System.Collections.ObjectModel.Collection.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def RemoveItem(self,*args):
  """
  RemoveItem(self: Collection[T],index: int)

   Removes the element at the specified index of the System.Collections.ObjectModel.Collection.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def SetItem(self,*args):
  """
  SetItem(self: Collection[T],index: int,item: T)

   Replaces the element at the specified index.

  

   index: The zero-based index of the element to replace.

   item: The new value for the element at the specified index. The value can be null for reference types.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.

  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,list=None):
  """
  __new__(cls: type)

  __new__(cls: type,list: IList[T])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of elements actually contained in the System.Collections.ObjectModel.Collection.



Get: Count(self: Collection[T]) -> int



"""

 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""



class KeyedCollection(Collection[TItem],IList[TItem],ICollection[TItem],IEnumerable[TItem],IEnumerable,IList,ICollection,IReadOnlyList[TItem],IReadOnlyCollection[TItem]):
 # no doc
 def ChangeItemKey(self,*args):
  """
  ChangeItemKey(self: KeyedCollection[TKey,TItem],item: TItem,newKey: TKey)

   Changes the key associated with the specified element in the lookup dictionary.

  

   item: The element to change the key of.

   newKey: The new key for item.
  """
  pass
 def ClearItems(self,*args):
  """
  ClearItems(self: KeyedCollection[TKey,TItem])

   Removes all elements from the System.Collections.ObjectModel.KeyedCollection.
  """
  pass
 def Contains(self,*__args):
  """
  Contains(self: KeyedCollection[TKey,TItem],key: TKey) -> bool

  

   Determines whether the collection contains an element with the specified key.

  

   key: The key to locate in the System.Collections.ObjectModel.KeyedCollection.

   Returns: true if the System.Collections.ObjectModel.KeyedCollection contains an element with the 

    specified key; otherwise,false.
  """
  pass
 def GetKeyForItem(self,*args):
  """
  GetKeyForItem(self: KeyedCollection[TKey,TItem],item: TItem) -> TKey

  

   When implemented in a derived class,extracts the key from the specified element.

  

   item: The element from which to extract the key.

   Returns: The key for the specified element.
  """
  pass
 def InsertItem(self,*args):
  """
  InsertItem(self: KeyedCollection[TKey,TItem],index: int,item: TItem)

   Inserts an element into the System.Collections.ObjectModel.KeyedCollection at the specified 

    index.

  

  

   index: The zero-based index at which item should be inserted.

   item: The object to insert.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: KeyedCollection[TKey,TItem],key: TKey) -> bool

  

   Removes the element with the specified key from the 

    System.Collections.ObjectModel.KeyedCollection.

  

  

   key: The key of the element to remove.

   Returns: true if the element is successfully removed; otherwise,false.  This method also returns false 

    if key is not found in the System.Collections.ObjectModel.KeyedCollection.
  """
  pass
 def RemoveItem(self,*args):
  """
  RemoveItem(self: KeyedCollection[TKey,TItem],index: int)

   Removes the element at the specified index of the System.Collections.ObjectModel.KeyedCollection.

  

   index: The index of the element to remove.
  """
  pass
 def SetItem(self,*args):
  """
  SetItem(self: KeyedCollection[TKey,TItem],index: int,item: TItem)

   Replaces the item at the specified index with the specified item.

  

   index: The zero-based index of the item to be replaced.

   item: The new item.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type)

  __new__(cls: type,comparer: IEqualityComparer[TKey])

  __new__(cls: type,comparer: IEqualityComparer[TKey],dictionaryCreationThreshold: int)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Comparer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the generic equality comparer that is used to determine equality of keys in the collection.



Get: Comparer(self: KeyedCollection[TKey,TItem]) -> IEqualityComparer[TKey]



"""

 Dictionary=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the lookup dictionary of the System.Collections.ObjectModel.KeyedCollection.



"""

 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""



class ObservableCollection(Collection[T],IList[T],ICollection[T],IEnumerable[T],IEnumerable,IList,ICollection,IReadOnlyList[T],IReadOnlyCollection[T],INotifyCollectionChanged,INotifyPropertyChanged):
 """
 ObservableCollection[T]()

 ObservableCollection[T](list: List[T])

 ObservableCollection[T](collection: IEnumerable[T])
 """
 def add_PropertyChanged(self,*args):
  """ add_PropertyChanged(self: ObservableCollection[T],value: PropertyChangedEventHandler) """
  pass
 def BlockReentrancy(self,*args):
  """
  BlockReentrancy(self: ObservableCollection[T]) -> IDisposable

  

   Disallows reentrant attempts to change this collection.

   Returns: An System.IDisposable object that can be used to dispose of the object.
  """
  pass
 def CheckReentrancy(self,*args):
  """
  CheckReentrancy(self: ObservableCollection[T])

   Checks for reentrant attempts to change this collection.
  """
  pass
 def ClearItems(self,*args):
  """
  ClearItems(self: ObservableCollection[T])

   Removes all items from the collection.
  """
  pass
 def InsertItem(self,*args):
  """
  InsertItem(self: ObservableCollection[T],index: int,item: T)

   Inserts an item into the collection at the specified index.

  

   index: The zero-based index at which item should be inserted.

   item: The object to insert.
  """
  pass
 def Move(self,oldIndex,newIndex):
  """
  Move(self: ObservableCollection[T],oldIndex: int,newIndex: int)

   Moves the item at the specified index to a new location in the collection.

  

   oldIndex: The zero-based index specifying the location of the item to be moved.

   newIndex: The zero-based index specifying the new location of the item.
  """
  pass
 def MoveItem(self,*args):
  """
  MoveItem(self: ObservableCollection[T],oldIndex: int,newIndex: int)

   Moves the item at the specified index to a new location in the collection.

  

   oldIndex: The zero-based index specifying the location of the item to be moved.

   newIndex: The zero-based index specifying the new location of the item.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: ObservableCollection[T],e: NotifyCollectionChangedEventArgs)

   Raises the System.Collections.ObjectModel.ObservableCollection event with the provided arguments.

  

   e: Arguments of the event being raised.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: ObservableCollection[T],e: PropertyChangedEventArgs)

   Raises the System.Collections.ObjectModel.ObservableCollection event with the provided arguments.

  

   e: Arguments of the event being raised.
  """
  pass
 def RemoveItem(self,*args):
  """
  RemoveItem(self: ObservableCollection[T],index: int)

   Removes the item at the specified index of the collection.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def remove_PropertyChanged(self,*args):
  """ remove_PropertyChanged(self: ObservableCollection[T],value: PropertyChangedEventHandler) """
  pass
 def SetItem(self,*args):
  """
  SetItem(self: ObservableCollection[T],index: int,item: T)

   Replaces the element at the specified index.

  

   index: The zero-based index of the element to replace.

   item: The new value for the element at the specified index.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,list: List[T])

  __new__(cls: type,collection: IEnumerable[T])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""


 CollectionChanged=None


class ReadOnlyCollection(object,IList[T],ICollection[T],IEnumerable[T],IEnumerable,IList,ICollection,IReadOnlyList[T],IReadOnlyCollection[T]):
 """ ReadOnlyCollection[T](list: IList[T]) """
 def Contains(self,value):
  """
  Contains(self: ReadOnlyCollection[T],value: T) -> bool

  

   Determines whether an element is in the System.Collections.ObjectModel.ReadOnlyCollection.

  

   value: The object to locate in the System.Collections.ObjectModel.ReadOnlyCollection. The value can be 

    null for reference types.

  

   Returns: true if value is found in the System.Collections.ObjectModel.ReadOnlyCollection; otherwise,

    false.
  """
  pass
 def CopyTo(self,array,index):
  """ CopyTo(self: ReadOnlyCollection[T],array: Array[T],index: int) """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: ReadOnlyCollection[T]) -> IEnumerator[T]

  

   Returns an enumerator that iterates through the 

    System.Collections.ObjectModel.ReadOnlyCollection.

  

   Returns: An System.Collections.Generic.IEnumerator for the 

    System.Collections.ObjectModel.ReadOnlyCollection.
  """
  pass
 def IndexOf(self,value):
  """
  IndexOf(self: ReadOnlyCollection[T],value: T) -> int

  

   Searches for the specified object and returns the zero-based index of the first occurrence 

    within the entire System.Collections.ObjectModel.ReadOnlyCollection.

  

  

   value: The object to locate in the System.Collections.Generic.List. The value can be null for reference 

    types.

  

   Returns: The zero-based index of the first occurrence of item within the entire 

    System.Collections.ObjectModel.ReadOnlyCollection,if found; otherwise,-1.
  """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: ICollection[T],item: T) -> bool

  

   Determines whether the System.Collections.Generic.ICollection contains a specific value.

  

   item: The object to locate in the System.Collections.Generic.ICollection.

   Returns: true if item is found in the System.Collections.Generic.ICollection; otherwise,false.

  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,list):
  """ __new__(cls: type,list: IList[T]) """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of elements contained in the System.Collections.ObjectModel.ReadOnlyCollection instance.



Get: Count(self: ReadOnlyCollection[T]) -> int



"""

 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Returns the System.Collections.Generic.IList that the System.Collections.ObjectModel.ReadOnlyCollection wraps.



"""



class ReadOnlyDictionary(object,IDictionary[TKey,TValue],ICollection[KeyValuePair[TKey,TValue]],IEnumerable[KeyValuePair[TKey,TValue]],IEnumerable,IDictionary,ICollection,IReadOnlyDictionary[TKey,TValue],IReadOnlyCollection[KeyValuePair[TKey,TValue]]):
 """ ReadOnlyDictionary[TKey,TValue](dictionary: IDictionary[TKey,TValue]) """
 def ContainsKey(self,key):
  """ ContainsKey(self: ReadOnlyDictionary[TKey,TValue],key: TKey) -> bool """
  pass
 def GetEnumerator(self):
  """ GetEnumerator(self: ReadOnlyDictionary[TKey,TValue]) -> IEnumerator[KeyValuePair[TKey,TValue]] """
  pass
 def TryGetValue(self,key,value):
  """ TryGetValue(self: ReadOnlyDictionary[TKey,TValue],key: TKey) -> (bool,TValue) """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IDictionary[TKey,TValue],key: TKey) -> bool

  

   Determines whether the System.Collections.Generic.IDictionary contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.Generic.IDictionary.

   Returns: true if the System.Collections.Generic.IDictionary contains an element with the key; otherwise,

    false.

  

  __contains__(self: IDictionary,key: object) -> bool

  

   Determines whether the System.Collections.IDictionary object contains an element with the 

    specified key.

  

  

   key: The key to locate in the System.Collections.IDictionary object.

   Returns: true if the System.Collections.IDictionary contains an element with the key; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,dictionary):
  """ __new__(cls: type,dictionary: IDictionary[TKey,TValue]) """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Count(self: ReadOnlyDictionary[TKey,TValue]) -> int



"""

 Dictionary=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Keys(self: ReadOnlyDictionary[TKey,TValue]) -> KeyCollection



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Values(self: ReadOnlyDictionary[TKey,TValue]) -> ValueCollection



"""


 KeyCollection=None
 ValueCollection=None


class ReadOnlyObservableCollection(ReadOnlyCollection[T],IList[T],ICollection[T],IEnumerable[T],IEnumerable,IList,ICollection,IReadOnlyList[T],IReadOnlyCollection[T],INotifyCollectionChanged,INotifyPropertyChanged):
 """ ReadOnlyObservableCollection[T](list: ObservableCollection[T]) """
 def add_CollectionChanged(self,*args):
  """ add_CollectionChanged(self: ReadOnlyObservableCollection[T],value: NotifyCollectionChangedEventHandler) """
  pass
 def add_PropertyChanged(self,*args):
  """ add_PropertyChanged(self: ReadOnlyObservableCollection[T],value: PropertyChangedEventHandler) """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: ReadOnlyObservableCollection[T],args: NotifyCollectionChangedEventArgs)

   Raises the System.Collections.ObjectModel.ReadOnlyObservableCollection event using the provided 

    arguments.

  

  

   args: Arguments of the event being raised.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: ReadOnlyObservableCollection[T],args: PropertyChangedEventArgs)

   Raises the System.Collections.ObjectModel.ReadOnlyObservableCollection event using the provided 

    arguments.

  

  

   args: Arguments of the event being raised.
  """
  pass
 def remove_CollectionChanged(self,*args):
  """ remove_CollectionChanged(self: ReadOnlyObservableCollection[T],value: NotifyCollectionChangedEventHandler) """
  pass
 def remove_PropertyChanged(self,*args):
  """ remove_PropertyChanged(self: ReadOnlyObservableCollection[T],value: PropertyChangedEventHandler) """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,list):
  """ __new__(cls: type,list: ObservableCollection[T]) """
  pass
 def __reduce_ex__(self,*args):
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Returns the System.Collections.Generic.IList that the System.Collections.ObjectModel.ReadOnlyCollection wraps.



"""






class CheckBoxRenderer(object):
 """ Provides methods used to render a check box control with or without visual styles. This class cannot be inherited. """
 @staticmethod
 def DrawCheckBox(g,glyphLocation,*__args):
  """
  DrawCheckBox(g: Graphics,glyphLocation: Point,textBounds: Rectangle,checkBoxText: str,font: Font,image: Image,imageBounds: Rectangle,focused: bool,state: CheckBoxState)

   Draws a check box control in the specified state and location,with the specified text and 

    image,and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the check box.

   glyphLocation: The System.Drawing.Point to draw the check box glyph at.

   textBounds: The System.Drawing.Rectangle to draw checkBoxText in.

   checkBoxText: The System.String to draw with the check box.

   font: The System.Drawing.Font to apply to checkBoxText.

   image: The System.Drawing.Image to draw with the check box.

   imageBounds: The System.Drawing.Rectangle that represents the dimensions of image.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.CheckBoxState values that specifies the visual 

    state of the check box.

  

  DrawCheckBox(g: Graphics,glyphLocation: Point,textBounds: Rectangle,checkBoxText: str,font: Font,flags: TextFormatFlags,image: Image,imageBounds: Rectangle,focused: bool,state: CheckBoxState)

   Draws a check box control in the specified state and location; with the specified text,text 

    formatting,and image; and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the check box.

   glyphLocation: The System.Drawing.Point to draw the check box glyph at.

   textBounds: The System.Drawing.Rectangle to draw checkBoxText in.

   checkBoxText: The System.String to draw with the check box.

   font: The System.Drawing.Font to apply to checkBoxText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   image: The System.Drawing.Image to draw with the check box.

   imageBounds: The System.Drawing.Rectangle that represents the dimensions of image.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.CheckBoxState values that specifies the visual 

    state of the check box.

  

  DrawCheckBox(g: Graphics,glyphLocation: Point,textBounds: Rectangle,checkBoxText: str,font: Font,flags: TextFormatFlags,focused: bool,state: CheckBoxState)

   Draws a check box control in the specified state and location,with the specified text and text 

    formatting,and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the check box.

   glyphLocation: The System.Drawing.Point to draw the check box glyph at.

   textBounds: The System.Drawing.Rectangle to draw checkBoxText in.

   checkBoxText: The System.String to draw with the check box.

   font: The System.Drawing.Font to apply to checkBoxText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.CheckBoxState values that specifies the visual 

    state of the check box.

  

  DrawCheckBox(g: Graphics,glyphLocation: Point,state: CheckBoxState)

   Draws a check box control in the specified state and location.

  

   g: The System.Drawing.Graphics used to draw the check box.

   glyphLocation: The System.Drawing.Point to draw the check box glyph at.

   state: One of the System.Windows.Forms.VisualStyles.CheckBoxState values that specifies the visual 

    state of the check box.

  

  DrawCheckBox(g: Graphics,glyphLocation: Point,textBounds: Rectangle,checkBoxText: str,font: Font,focused: bool,state: CheckBoxState)

   Draws a check box control in the specified state and location,with the specified text,and with 

    an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the check box.

   glyphLocation: The System.Drawing.Point to draw the check box glyph at.

   textBounds: The System.Drawing.Rectangle to draw checkBoxText in.

   checkBoxText: The System.String to draw with the check box.

   font: The System.Drawing.Font to apply to checkBoxText.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.CheckBoxState values that specifies the visual 

    state of the check box.
  """
  pass
 @staticmethod
 def DrawParentBackground(g,bounds,childControl):
  """
  DrawParentBackground(g: Graphics,bounds: Rectangle,childControl: Control)

   Draws the background of a control's parent in the specified area.

  

   g: The System.Drawing.Graphics used to draw the background of the parent of childControl.

   bounds: The System.Drawing.Rectangle in which to draw the parent control's background. This rectangle 

    

   childControl: The control whose parent's background will be drawn.
  """
  pass
 @staticmethod
 def GetGlyphSize(g,state):
  """
  GetGlyphSize(g: Graphics,state: CheckBoxState) -> Size

  

   Returns the size of the check box glyph.

  

   g: The System.Drawing.Graphics this operation will use.

   state: One of the System.Windows.Forms.VisualStyles.CheckBoxState values that specifies the visual 

    state of the check box.

  

   Returns: A System.Drawing.Size that represents the size of the check box glyph.
  """
  pass
 @staticmethod
 def IsBackgroundPartiallyTransparent(state):
  """
  IsBackgroundPartiallyTransparent(state: CheckBoxState) -> bool

  

   Indicates whether the background of the check box has semitransparent or alpha-blended pieces.

  

   state: One of the System.Windows.Forms.VisualStyles.CheckBoxState values that specifies the visual 

    state of the check box.

  

   Returns: true if the background of the check box has semitransparent or alpha-blended pieces; otherwise,

    false.
  """
  pass
 RenderMatchingApplicationState=True




class DataGridViewCellStyleContentChangedEventArgs(EventArgs):
 """ Provides data for the System.Windows.Forms.DataGridView.CellStyleContentChanged event. """
 CellStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the changed System.Windows.Forms.DataGridViewCellStyle.



Get: CellStyle(self: DataGridViewCellStyleContentChangedEventArgs) -> DataGridViewCellStyle



"""

 CellStyleScope=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the scope that is affected by the changed cell style.



Get: CellStyleScope(self: DataGridViewCellStyleContentChangedEventArgs) -> DataGridViewCellStyleScopes



"""





# encoding: utf-8
# module System.Windows.Media.Animation calls itself Animation
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from Animation_parts.IAnimatable import IAnimatable
from Animation_parts.Animatable import Animatable
from Animation_parts.Clock import Clock
from Animation_parts.AnimationClock import AnimationClock
from Animation_parts.AnimationException import AnimationException
from Animation_parts.Timeline import Timeline
from Animation_parts.AnimationTimeline import AnimationTimeline
from Animation_parts.IEasingFunction import IEasingFunction
from Animation_parts.EasingFunctionBase import EasingFunctionBase
from Animation_parts.BackEase import BackEase
from Animation_parts.BooleanAnimationBase import BooleanAnimationBase
from Animation_parts.IKeyFrameAnimation import IKeyFrameAnimation
from Animation_parts.BooleanAnimationUsingKeyFrames import BooleanAnimationUsingKeyFrames
from Animation_parts.IKeyFrame import IKeyFrame
from Animation_parts.BooleanKeyFrame import BooleanKeyFrame
from Animation_parts.BooleanKeyFrameCollection import BooleanKeyFrameCollection
from Animation_parts.BounceEase import BounceEase
from Animation_parts.ByteAnimationBase import ByteAnimationBase
from Animation_parts.ByteAnimation import ByteAnimation
from Animation_parts.ByteAnimationUsingKeyFrames import ByteAnimationUsingKeyFrames
from Animation_parts.ByteKeyFrame import ByteKeyFrame
from Animation_parts.ByteKeyFrameCollection import ByteKeyFrameCollection
from Animation_parts.CharAnimationBase import CharAnimationBase
from Animation_parts.CharAnimationUsingKeyFrames import CharAnimationUsingKeyFrames
from Animation_parts.CharKeyFrame import CharKeyFrame
from Animation_parts.CharKeyFrameCollection import CharKeyFrameCollection
from Animation_parts.CircleEase import CircleEase
from Animation_parts.ClockCollection import ClockCollection
from Animation_parts.ClockController import ClockController
from Animation_parts.ClockGroup import ClockGroup
from Animation_parts.ClockState import ClockState
from Animation_parts.ColorAnimationBase import ColorAnimationBase
from Animation_parts.ColorAnimation import ColorAnimation
from Animation_parts.ColorAnimationUsingKeyFrames import ColorAnimationUsingKeyFrames
from Animation_parts.ColorKeyFrame import ColorKeyFrame
from Animation_parts.ColorKeyFrameCollection import ColorKeyFrameCollection
from Animation_parts.CubicEase import CubicEase
from Animation_parts.DecimalAnimationBase import DecimalAnimationBase
from Animation_parts.DecimalAnimation import DecimalAnimation
from Animation_parts.DecimalAnimationUsingKeyFrames import DecimalAnimationUsingKeyFrames
from Animation_parts.DecimalKeyFrame import DecimalKeyFrame
from Animation_parts.DecimalKeyFrameCollection import DecimalKeyFrameCollection
from Animation_parts.DiscreteBooleanKeyFrame import DiscreteBooleanKeyFrame
from Animation_parts.DiscreteByteKeyFrame import DiscreteByteKeyFrame
from Animation_parts.DiscreteCharKeyFrame import DiscreteCharKeyFrame
from Animation_parts.DiscreteColorKeyFrame import DiscreteColorKeyFrame
from Animation_parts.DiscreteDecimalKeyFrame import DiscreteDecimalKeyFrame
from Animation_parts.DoubleKeyFrame import DoubleKeyFrame
from Animation_parts.DiscreteDoubleKeyFrame import DiscreteDoubleKeyFrame
from Animation_parts.Int16KeyFrame import Int16KeyFrame
from Animation_parts.DiscreteInt16KeyFrame import DiscreteInt16KeyFrame
from Animation_parts.Int32KeyFrame import Int32KeyFrame
from Animation_parts.DiscreteInt32KeyFrame import DiscreteInt32KeyFrame
from Animation_parts.Int64KeyFrame import Int64KeyFrame
from Animation_parts.DiscreteInt64KeyFrame import DiscreteInt64KeyFrame
from Animation_parts.MatrixKeyFrame import MatrixKeyFrame
from Animation_parts.DiscreteMatrixKeyFrame import DiscreteMatrixKeyFrame
from Animation_parts.ObjectKeyFrame import ObjectKeyFrame
from Animation_parts.DiscreteObjectKeyFrame import DiscreteObjectKeyFrame
from Animation_parts.Point3DKeyFrame import Point3DKeyFrame
from Animation_parts.DiscretePoint3DKeyFrame import DiscretePoint3DKeyFrame
from Animation_parts.PointKeyFrame import PointKeyFrame
from Animation_parts.DiscretePointKeyFrame import DiscretePointKeyFrame
from Animation_parts.QuaternionKeyFrame import QuaternionKeyFrame
from Animation_parts.DiscreteQuaternionKeyFrame import DiscreteQuaternionKeyFrame
from Animation_parts.RectKeyFrame import RectKeyFrame
from Animation_parts.DiscreteRectKeyFrame import DiscreteRectKeyFrame
from Animation_parts.Rotation3DKeyFrame import Rotation3DKeyFrame
from Animation_parts.DiscreteRotation3DKeyFrame import DiscreteRotation3DKeyFrame
from Animation_parts.SingleKeyFrame import SingleKeyFrame
from Animation_parts.DiscreteSingleKeyFrame import DiscreteSingleKeyFrame
from Animation_parts.SizeKeyFrame import SizeKeyFrame
from Animation_parts.DiscreteSizeKeyFrame import DiscreteSizeKeyFrame
from Animation_parts.StringKeyFrame import StringKeyFrame
from Animation_parts.DiscreteStringKeyFrame import DiscreteStringKeyFrame
from Animation_parts.Vector3DKeyFrame import Vector3DKeyFrame
from Animation_parts.DiscreteVector3DKeyFrame import DiscreteVector3DKeyFrame
from Animation_parts.VectorKeyFrame import VectorKeyFrame
from Animation_parts.DiscreteVectorKeyFrame import DiscreteVectorKeyFrame
from Animation_parts.DoubleAnimationBase import DoubleAnimationBase
from Animation_parts.DoubleAnimation import DoubleAnimation
from Animation_parts.DoubleAnimationUsingKeyFrames import DoubleAnimationUsingKeyFrames
from Animation_parts.DoubleAnimationUsingPath import DoubleAnimationUsingPath
from Animation_parts.DoubleKeyFrameCollection import DoubleKeyFrameCollection
from Animation_parts.EasingByteKeyFrame import EasingByteKeyFrame
from Animation_parts.EasingColorKeyFrame import EasingColorKeyFrame
from Animation_parts.EasingDecimalKeyFrame import EasingDecimalKeyFrame
from Animation_parts.EasingDoubleKeyFrame import EasingDoubleKeyFrame
from Animation_parts.EasingInt16KeyFrame import EasingInt16KeyFrame
from Animation_parts.EasingInt32KeyFrame import EasingInt32KeyFrame
from Animation_parts.EasingInt64KeyFrame import EasingInt64KeyFrame
from Animation_parts.EasingMode import EasingMode
from Animation_parts.EasingPoint3DKeyFrame import EasingPoint3DKeyFrame
from Animation_parts.EasingPointKeyFrame import EasingPointKeyFrame
from Animation_parts.EasingQuaternionKeyFrame import EasingQuaternionKeyFrame
from Animation_parts.EasingRectKeyFrame import EasingRectKeyFrame
from Animation_parts.EasingRotation3DKeyFrame import EasingRotation3DKeyFrame
from Animation_parts.EasingSingleKeyFrame import EasingSingleKeyFrame
from Animation_parts.EasingSizeKeyFrame import EasingSizeKeyFrame
from Animation_parts.EasingVector3DKeyFrame import EasingVector3DKeyFrame
from Animation_parts.EasingVectorKeyFrame import EasingVectorKeyFrame
from Animation_parts.ElasticEase import ElasticEase
from Animation_parts.ExponentialEase import ExponentialEase
from Animation_parts.FillBehavior import FillBehavior
from Animation_parts.HandoffBehavior import HandoffBehavior
from Animation_parts.Int16AnimationBase import Int16AnimationBase
from Animation_parts.Int16Animation import Int16Animation
from Animation_parts.Int16AnimationUsingKeyFrames import Int16AnimationUsingKeyFrames
from Animation_parts.Int16KeyFrameCollection import Int16KeyFrameCollection
from Animation_parts.Int32AnimationBase import Int32AnimationBase
from Animation_parts.Int32Animation import Int32Animation
from Animation_parts.Int32AnimationUsingKeyFrames import Int32AnimationUsingKeyFrames
from Animation_parts.Int32KeyFrameCollection import Int32KeyFrameCollection
from Animation_parts.Int64AnimationBase import Int64AnimationBase
from Animation_parts.Int64Animation import Int64Animation
from Animation_parts.Int64AnimationUsingKeyFrames import Int64AnimationUsingKeyFrames
from Animation_parts.Int64KeyFrameCollection import Int64KeyFrameCollection
from Animation_parts.KeySpline import KeySpline
from Animation_parts.KeyTime import KeyTime
from Animation_parts.KeyTimeType import KeyTimeType
from Animation_parts.LinearByteKeyFrame import LinearByteKeyFrame
from Animation_parts.LinearColorKeyFrame import LinearColorKeyFrame
from Animation_parts.LinearDecimalKeyFrame import LinearDecimalKeyFrame
from Animation_parts.LinearDoubleKeyFrame import LinearDoubleKeyFrame
from Animation_parts.LinearInt16KeyFrame import LinearInt16KeyFrame
from Animation_parts.LinearInt32KeyFrame import LinearInt32KeyFrame
from Animation_parts.LinearInt64KeyFrame import LinearInt64KeyFrame
from Animation_parts.LinearPoint3DKeyFrame import LinearPoint3DKeyFrame
from Animation_parts.LinearPointKeyFrame import LinearPointKeyFrame
from Animation_parts.LinearQuaternionKeyFrame import LinearQuaternionKeyFrame
from Animation_parts.LinearRectKeyFrame import LinearRectKeyFrame
from Animation_parts.LinearRotation3DKeyFrame import LinearRotation3DKeyFrame
from Animation_parts.LinearSingleKeyFrame import LinearSingleKeyFrame
from Animation_parts.LinearSizeKeyFrame import LinearSizeKeyFrame
from Animation_parts.LinearVector3DKeyFrame import LinearVector3DKeyFrame
from Animation_parts.LinearVectorKeyFrame import LinearVectorKeyFrame
from Animation_parts.MatrixAnimationBase import MatrixAnimationBase
from Animation_parts.MatrixAnimationUsingKeyFrames import MatrixAnimationUsingKeyFrames
from Animation_parts.MatrixAnimationUsingPath import MatrixAnimationUsingPath
from Animation_parts.MatrixKeyFrameCollection import MatrixKeyFrameCollection
from Animation_parts.ObjectAnimationBase import ObjectAnimationBase
from Animation_parts.ObjectAnimationUsingKeyFrames import ObjectAnimationUsingKeyFrames
from Animation_parts.ObjectKeyFrameCollection import ObjectKeyFrameCollection
from Animation_parts.TimelineGroup import TimelineGroup
from Animation_parts.ParallelTimeline import ParallelTimeline
from Animation_parts.PathAnimationSource import PathAnimationSource
from Animation_parts.Point3DAnimationBase import Point3DAnimationBase
from Animation_parts.Point3DAnimation import Point3DAnimation
from Animation_parts.Point3DAnimationUsingKeyFrames import Point3DAnimationUsingKeyFrames
from Animation_parts.Point3DKeyFrameCollection import Point3DKeyFrameCollection
from Animation_parts.PointAnimationBase import PointAnimationBase
from Animation_parts.PointAnimation import PointAnimation
from Animation_parts.PointAnimationUsingKeyFrames import PointAnimationUsingKeyFrames
from Animation_parts.PointAnimationUsingPath import PointAnimationUsingPath
from Animation_parts.PointKeyFrameCollection import PointKeyFrameCollection
from Animation_parts.PowerEase import PowerEase
from Animation_parts.QuadraticEase import QuadraticEase
from Animation_parts.QuarticEase import QuarticEase
from Animation_parts.QuaternionAnimationBase import QuaternionAnimationBase
from Animation_parts.QuaternionAnimation import QuaternionAnimation
from Animation_parts.QuaternionAnimationUsingKeyFrames import QuaternionAnimationUsingKeyFrames
from Animation_parts.QuaternionKeyFrameCollection import QuaternionKeyFrameCollection
from Animation_parts.QuinticEase import QuinticEase
from Animation_parts.RectAnimationBase import RectAnimationBase
from Animation_parts.RectAnimation import RectAnimation
from Animation_parts.RectAnimationUsingKeyFrames import RectAnimationUsingKeyFrames
from Animation_parts.RectKeyFrameCollection import RectKeyFrameCollection
from Animation_parts.RepeatBehavior import RepeatBehavior
from Animation_parts.RepeatBehaviorConverter import RepeatBehaviorConverter
from Animation_parts.Rotation3DAnimationBase import Rotation3DAnimationBase
from Animation_parts.Rotation3DAnimation import Rotation3DAnimation
from Animation_parts.Rotation3DAnimationUsingKeyFrames import Rotation3DAnimationUsingKeyFrames
from Animation_parts.Rotation3DKeyFrameCollection import Rotation3DKeyFrameCollection
from Animation_parts.SineEase import SineEase
from Animation_parts.SingleAnimationBase import SingleAnimationBase
from Animation_parts.SingleAnimation import SingleAnimation
from Animation_parts.SingleAnimationUsingKeyFrames import SingleAnimationUsingKeyFrames
from Animation_parts.SingleKeyFrameCollection import SingleKeyFrameCollection
from Animation_parts.SizeAnimationBase import SizeAnimationBase
from Animation_parts.SizeAnimation import SizeAnimation
from Animation_parts.SizeAnimationUsingKeyFrames import SizeAnimationUsingKeyFrames
from Animation_parts.SizeKeyFrameCollection import SizeKeyFrameCollection
from Animation_parts.SlipBehavior import SlipBehavior
from Animation_parts.SplineByteKeyFrame import SplineByteKeyFrame
from Animation_parts.SplineColorKeyFrame import SplineColorKeyFrame
from Animation_parts.SplineDecimalKeyFrame import SplineDecimalKeyFrame
from Animation_parts.SplineDoubleKeyFrame import SplineDoubleKeyFrame
from Animation_parts.SplineInt16KeyFrame import SplineInt16KeyFrame
from Animation_parts.SplineInt32KeyFrame import SplineInt32KeyFrame
from Animation_parts.SplineInt64KeyFrame import SplineInt64KeyFrame
from Animation_parts.SplinePoint3DKeyFrame import SplinePoint3DKeyFrame
from Animation_parts.SplinePointKeyFrame import SplinePointKeyFrame
from Animation_parts.SplineQuaternionKeyFrame import SplineQuaternionKeyFrame
from Animation_parts.SplineRectKeyFrame import SplineRectKeyFrame
from Animation_parts.SplineRotation3DKeyFrame import SplineRotation3DKeyFrame
from Animation_parts.SplineSingleKeyFrame import SplineSingleKeyFrame
from Animation_parts.SplineSizeKeyFrame import SplineSizeKeyFrame
from Animation_parts.SplineVector3DKeyFrame import SplineVector3DKeyFrame
from Animation_parts.SplineVectorKeyFrame import SplineVectorKeyFrame
from Animation_parts.StringAnimationBase import StringAnimationBase
from Animation_parts.StringAnimationUsingKeyFrames import StringAnimationUsingKeyFrames
from Animation_parts.StringKeyFrameCollection import StringKeyFrameCollection
from Animation_parts.TimelineCollection import TimelineCollection
from Animation_parts.TimeSeekOrigin import TimeSeekOrigin
from Animation_parts.Vector3DAnimationBase import Vector3DAnimationBase
from Animation_parts.Vector3DAnimation import Vector3DAnimation
from Animation_parts.Vector3DAnimationUsingKeyFrames import Vector3DAnimationUsingKeyFrames
from Animation_parts.Vector3DKeyFrameCollection import Vector3DKeyFrameCollection
from Animation_parts.VectorAnimationBase import VectorAnimationBase
from Animation_parts.VectorAnimation import VectorAnimation
from Animation_parts.VectorAnimationUsingKeyFrames import VectorAnimationUsingKeyFrames
from Animation_parts.VectorKeyFrameCollection import VectorKeyFrameCollection



class IKeyFrameAnimation:
 """ An System.Windows.Media.Animation.IKeyFrameAnimation interface implementation provides untyped access to key frame collection members. """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 KeyFrames=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an ordered collection System.Windows.Media.Animation.IKeyFrameAnimation.KeyFrames associated with this animation sequence.



Get: KeyFrames(self: IKeyFrameAnimation) -> IList



Set: KeyFrames(self: IKeyFrameAnimation)=value

"""





class Activator(object,_Activator):
 """ Contains methods to create types of objects locally or remotely,or obtain references to existing remote objects. This class cannot be inherited. """
 @staticmethod
 def CreateComInstanceFrom(assemblyName,typeName,hashValue=None,hashAlgorithm=None):
  """
  CreateComInstanceFrom(assemblyName: str,typeName: str,hashValue: Array[Byte],hashAlgorithm: AssemblyHashAlgorithm) -> ObjectHandle

  

   Creates an instance of the COM object whose name is specified,using the named assembly file and 

    the default constructor.

  

  

   assemblyName: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   hashValue: The value of the computed hash code.

   hashAlgorithm: The hash algorithm used for hashing files and generating the strong name.

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateComInstanceFrom(assemblyName: str,typeName: str) -> ObjectHandle

  

   Creates an instance of the COM object whose name is specified,using the named assembly file and 

    the constructor that best matches the specified parameters.

  

  

   assemblyName: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   Returns: A handle that must be unwrapped to access the newly created instance.
  """
  pass
 @staticmethod
 def CreateInstance(*__args):
  """
  CreateInstance(assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly and the 

    constructor that best matches the specified parameters.

  

  

   assemblyName: The name of the assembly where the type named typeName is sought. If assemblyName is null,the 

    executing assembly is searched.

  

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstance(domain: AppDomain,assemblyName: str,typeName: str) -> ObjectHandle

  

   Creates an instance of the type whose name is specified in the specified remote domain,using 

    the named assembly and default constructor.

  

  

   domain: The remote domain where the type named typeName is created.

   assemblyName: The name of the assembly where the type named typeName is sought. If assemblyName is null,the 

    executing assembly is searched.

  

   typeName: The name of the preferred type.

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstance[T]() -> T

  CreateInstance(assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityInfo: Evidence) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly and the 

    constructor that best matches the specified parameters.

  

  

   assemblyName: The name of the assembly where the type named typeName is sought. If assemblyName is null,the 

    executing assembly is searched.

  

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityInfo: Information used to make security policy decisions and grant code permissions.

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstance(activationContext: ActivationContext) -> ObjectHandle

  

   Creates an instance of the type designated by the specified System.ActivationContext object.

  

   activationContext: An activation context object that specifies the object to create.

   Returns: A handle that must be unwrapped to access the newly created object.

  CreateInstance(activationContext: ActivationContext,activationCustomData: Array[str]) -> ObjectHandle

  

   Creates an instance of the type that is designated by the specified System.ActivationContext 

    object and activated with the specified custom activation data.

  

  

   activationContext: An activation context object that specifies the object to create.

   activationCustomData: An array of Unicode strings that contain custom activation data.

   Returns: A handle that must be unwrapped to access the newly created object.

  CreateInstance(domain: AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> ObjectHandle

  

   Creates an instance of the type whose name is specified in the specified remote domain,using 

    the named assembly and the constructor that best matches the specified parameters.

  

  

   domain: The domain where the type named typeName is created.

   assemblyName: The name of the assembly where the type named typeName is sought. If assemblyName is null,the 

    executing assembly is searched.

  

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to make security policy decisions and grant code permissions.

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstance(domain: AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates an instance of the type whose name is specified in the specified remote domain,using 

    the named assembly and the constructor that best matches the specified parameters.

  

  

   domain: The domain where the type named typeName is created.

   assemblyName: The name of the assembly where the type named typeName is sought. If assemblyName is null,the 

    executing assembly is searched.

  

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstance(type: Type,*args: Array[object]) -> object

  

   Creates an instance of the specified type using the constructor that best matches the specified 

    parameters.

  

  

   type: The type of object to create.

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   Returns: A reference to the newly created object.

  CreateInstance(type: Type,args: Array[object],activationAttributes: Array[object]) -> object

  

   Creates an instance of the specified type using the constructor that best matches the specified 

    parameters.

  

  

   type: The type of object to create.

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A reference to the newly created object.

  CreateInstance(type: Type,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo) -> object

  

   Creates an instance of the specified type using the constructor that best matches the specified 

    parameters.

  

  

   type: The type of object to create.

   bindingAttr: A combination of zero or more bit flags that affect the search for the type constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the type constructor. If binder is 

    null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the type constructor. If culture is null,the System.Globalization.CultureInfo for the current 

    thread is used.

  

   Returns: A reference to the newly created object.

  CreateInstance(type: Type,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> object

  

   Creates an instance of the specified type using the constructor that best matches the specified 

    parameters.

  

  

   type: The type of object to create.

   bindingAttr: A combination of zero or more bit flags that affect the search for the type constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the type constructor. If binder is 

    null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the type constructor. If culture is null,the System.Globalization.CultureInfo for the current 

    thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A reference to the newly created object.

  CreateInstance(assemblyName: str,typeName: str,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly and default 

    constructor.

  

  

   assemblyName: The name of the assembly where the type named typeName is sought. If assemblyName is null,the 

    executing assembly is searched.

  

   typeName: The name of the preferred type.

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstance(type: Type,nonPublic: bool) -> object

  

   Creates an instance of the specified type using that type's default constructor.

  

   type: The type of object to create.

   nonPublic: true if a public or nonpublic default constructor can match; false if only a public default 

    constructor can match.

  

   Returns: A reference to the newly created object.

  CreateInstance(type: Type) -> object

  

   Creates an instance of the specified type using that type's default constructor.

  

   type: The type of object to create.

   Returns: A reference to the newly created object.

  CreateInstance(assemblyName: str,typeName: str) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly and default 

    constructor.

  

  

   assemblyName: The name of the assembly where the type named typeName is sought. If assemblyName is null,the 

    executing assembly is searched.

  

   typeName: The name of the preferred type.

   Returns: A handle that must be unwrapped to access the newly created instance.
  """
  pass
 @staticmethod
 def CreateInstanceFrom(*__args):
  """
  CreateInstanceFrom(domain: AppDomain,assemblyFile: str,typeName: str) -> ObjectHandle

  

   Creates an instance of the type whose name is specified in the specified remote domain,using 

    the named assembly file and default constructor.

  

  

   domain: The remote domain where the type named typeName is created.

   assemblyFile: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstanceFrom(domain: AppDomain,assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> ObjectHandle

  

   Creates an instance of the type whose name is specified in the specified remote domain,using 

    the named assembly file and the constructor that best matches the specified parameters.

  

  

   domain: The remote domain where the type named typeName is created.

   assemblyFile: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to make security policy decisions and grant code permissions.

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstanceFrom(domain: AppDomain,assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates an instance of the type whose name is specified in the specified remote domain,using 

    the named assembly file and the constructor that best matches the specified parameters.

  

  

   domain: The remote domain where the type named typeName is created.

   assemblyFile: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstanceFrom(assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly file and the 

    constructor that best matches the specified parameters.

  

  

   assemblyFile: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstanceFrom(assemblyFile: str,typeName: str) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly file and 

    default constructor.

  

  

   assemblyFile: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstanceFrom(assemblyFile: str,typeName: str,activationAttributes: Array[object]) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly file and 

    default constructor.

  

  

   assemblyFile: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: A handle that must be unwrapped to access the newly created instance.

  CreateInstanceFrom(assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityInfo: Evidence) -> ObjectHandle

  

   Creates an instance of the type whose name is specified,using the named assembly file and the 

    constructor that best matches the specified parameters.

  

  

   assemblyFile: The name of a file that contains an assembly where the type named typeName is sought.

   typeName: The name of the preferred type.

   ignoreCase: true to specify that the search for typeName is not case-sensitive; false to specify that the 

    search is case-sensitive.

  

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that uses bindingAttr and args to seek and identify the typeName constructor. If 

    binder is null,the default binder is used.

  

   args: An array of arguments that match in number,order,and type the parameters of the constructor to 

    invoke. If args is an empty array or null,the constructor that takes no parameters (the default 

    constructor) is invoked.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. This is typically an 

    array that contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityInfo: Information used to make security policy decisions and grant code permissions.

   Returns: A handle that must be unwrapped to access the newly created instance.
  """
  pass
 @staticmethod
 def GetObject(type,url,state=None):
  """
  GetObject(type: Type,url: str,state: object) -> object

  

   Creates a proxy for the well-known object indicated by the specified type,URL,and channel data.

  

   type: The type of the well-known object to which you want to connect.

   url: The URL of the well-known object.

   state: Channel-specific data or null.

   Returns: A proxy that points to an endpoint served by the requested well-known object.

  GetObject(type: Type,url: str) -> object

  

   Creates a proxy for the well-known object indicated by the specified type and URL.

  

   type: The type of the well-known object to which you want to connect.

   url: The URL of the well-known object.

   Returns: A proxy that points to an endpoint served by the requested well-known object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass



class TypeLibConverter(object,ITypeLibConverter):
 """
 Provides a set of services that convert a managed assembly to a COM type library and vice versa.

 

 TypeLibConverter()
 """
 def ConvertAssemblyToTypeLib(self,assembly,strTypeLibName,flags,notifySink):
  """
  ConvertAssemblyToTypeLib(self: TypeLibConverter,assembly: Assembly,strTypeLibName: str,flags: TypeLibExporterFlags,notifySink: ITypeLibExporterNotifySink) -> object

  

   Converts an assembly to a COM type library.

  

   assembly: The assembly to convert.

   strTypeLibName: The file name of the resulting type library.

   flags: A System.Runtime.InteropServices.TypeLibExporterFlags value indicating any special settings.

   notifySink: The System.Runtime.InteropServices.ITypeLibExporterNotifySink interface implemented by the 

    caller.

  

   Returns: An object that implements the ITypeLib interface.
  """
  pass
 def ConvertTypeLibToAssembly(self,typeLib,asmFileName,flags,notifySink,publicKey,keyPair,*__args):
  """
  ConvertTypeLibToAssembly(self: TypeLibConverter,typeLib: object,asmFileName: str,flags: TypeLibImporterFlags,notifySink: ITypeLibImporterNotifySink,publicKey: Array[Byte],keyPair: StrongNameKeyPair,asmNamespace: str,asmVersion: Version) -> AssemblyBuilder

  

   Converts a COM type library to an assembly.

  

   typeLib: The object that implements the ITypeLib interface.

   asmFileName: The file name of the resulting assembly.

   flags: A System.Runtime.InteropServices.TypeLibImporterFlags value indicating any special settings.

   notifySink: System.Runtime.InteropServices.ITypeLibImporterNotifySink interface implemented by the caller.

   publicKey: A byte array containing the public key.

   keyPair: A System.Reflection.StrongNameKeyPair object containing the public and private cryptographic key 

    pair.

  

   asmNamespace: The namespace for the resulting assembly.

   asmVersion: The version of the resulting assembly. If null,the version of the type library is used.

   Returns: An System.Reflection.Emit.AssemblyBuilder object containing the converted type library.

  ConvertTypeLibToAssembly(self: TypeLibConverter,typeLib: object,asmFileName: str,flags: int,notifySink: ITypeLibImporterNotifySink,publicKey: Array[Byte],keyPair: StrongNameKeyPair,unsafeInterfaces: bool) -> AssemblyBuilder

  

   Converts a COM type library to an assembly.

  

   typeLib: The object that implements the ITypeLib interface.

   asmFileName: The file name of the resulting assembly.

   flags: A System.Runtime.InteropServices.TypeLibImporterFlags value indicating any special settings.

   notifySink: System.Runtime.InteropServices.ITypeLibImporterNotifySink interface implemented by the caller.

   publicKey: A byte array containing the public key.

   keyPair: A System.Reflection.StrongNameKeyPair object containing the public and private cryptographic key 

    pair.

  

   unsafeInterfaces: If true,the interfaces require link time checks for 

    System.Security.Permissions.SecurityPermissionFlag.UnmanagedCode permission. If false,the 

    interfaces require run time checks that require a stack walk and are more expensive,but help 

    provide greater protection.

  

   Returns: An System.Reflection.Emit.AssemblyBuilder object containing the converted type library.
  """
  pass
 def GetPrimaryInteropAssembly(self,g,major,minor,lcid,asmName,asmCodeBase):
  """
  GetPrimaryInteropAssembly(self: TypeLibConverter,g: Guid,major: int,minor: int,lcid: int) -> (bool,str,str)

  

   Gets the name and code base of a primary interop assembly for a specified type library.

  

   g: The GUID of the type library.

   major: The major version number of the type library.

   minor: The minor version number of the type library.

   lcid: The LCID of the type library.

   Returns: true if the primary interop assembly was found in the registry; otherwise false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass



class OperatingSystem(object,ICloneable,ISerializable):
 """
 Represents information about an operating system,such as the version and platform identifier. This class cannot be inherited.

 

 OperatingSystem(platform: PlatformID,version: Version)
 """
 def Clone(self):
  """
  Clone(self: OperatingSystem) -> object

  

   Creates an System.OperatingSystem object that is identical to this instance.

   Returns: An System.OperatingSystem object that is a copy of this instance.
  """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: OperatingSystem,info: SerializationInfo,context: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo object with the data necessary to 

    deserialize this instance.

  

  

   info: The object to populate with serialization information.

   context: The place to store and retrieve serialized data. Reserved for future use.
  """
  pass
 def ToString(self):
  """
  ToString(self: OperatingSystem) -> str

  

   Converts the value of this System.OperatingSystem object to its equivalent string representation.

   Returns: The string representation of the values returned by the System.OperatingSystem.Platform,

    System.OperatingSystem.Version,and System.OperatingSystem.ServicePack properties.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,platform,version):
  """ __new__(cls: type,platform: PlatformID,version: Version) """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 Platform=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.PlatformID enumeration value that identifies the operating system platform.



Get: Platform(self: OperatingSystem) -> PlatformID



"""

 ServicePack=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the service pack version represented by this System.OperatingSystem object.



Get: ServicePack(self: OperatingSystem) -> str



"""

 Version=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Version object that identifies the operating system.



Get: Version(self: OperatingSystem) -> Version



"""

 VersionString=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the concatenated string representation of the platform identifier,version,and service pack that are currently installed on the operating system.



Get: VersionString(self: OperatingSystem) -> str



"""


